summaryrefslogtreecommitdiffstats
path: root/src/partcontroller.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:25 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:25 -0600
commit1623fe64102c18ab098b79656b80f28cef840756 (patch)
tree78f35fef11ea3dbbca1ba4c99937736a1a0894cf /src/partcontroller.cpp
parentb6ba5d642f3fc7d320e3d6f4650eb259a3a52b04 (diff)
downloadtdevelop-1623fe64102c18ab098b79656b80f28cef840756.tar.gz
tdevelop-1623fe64102c18ab098b79656b80f28cef840756.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit b6ba5d642f3fc7d320e3d6f4650eb259a3a52b04.
Diffstat (limited to 'src/partcontroller.cpp')
-rw-r--r--src/partcontroller.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/src/partcontroller.cpp b/src/partcontroller.cpp
index 50659803..65257b1f 100644
--- a/src/partcontroller.cpp
+++ b/src/partcontroller.cpp
@@ -4,7 +4,7 @@
#include <tqpopupmenu.h>
#include <tqfile.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqmap.h>
#include <tqlabel.h>
#include <tqradiobutton.h>
@@ -131,7 +131,7 @@ void PartController::setupActions()
newAction->setWhatsThis( i18n("<b>Open file</b><p>Opens an existing file without adding it to the project.</p>") );
m_openRecentAction = KStdAction::openRecent( this, TQT_SLOT(slotOpenRecent(const KURL&) ), ac, "file_open_recent" );
- m_openRecentAction->setWhatsThis(TQString("<b>%1</b><p>%2").arg(beautifyToolTip(m_openRecentAction->text())).arg(i18n("Opens recently opened file.")));
+ m_openRecentAction->setWhatsThis(TQString("<b>%1</b><p>%2").tqarg(beautifyToolTip(m_openRecentAction->text())).tqarg(i18n("Opens recently opened file.")));
m_openRecentAction->loadEntries( kapp->config(), "RecentFiles" );
m_saveAllFilesAction = new KAction(i18n("Save Al&l"), 0, this, TQT_SLOT(slotSaveAllFiles()), ac, "file_save_all");
@@ -146,7 +146,7 @@ void PartController::setupActions()
m_closeWindowAction = KStdAction::close(this, TQT_SLOT(slotCloseWindow()), ac, "file_close");
m_closeWindowAction->setToolTip( i18n("Close current file") );
- m_closeWindowAction->setWhatsThis(TQString("<b>%1</b><p>%2").arg(beautifyToolTip(m_closeWindowAction->text())).arg(i18n("Closes current file.")));
+ m_closeWindowAction->setWhatsThis(TQString("<b>%1</b><p>%2").tqarg(beautifyToolTip(m_closeWindowAction->text())).tqarg(i18n("Closes current file.")));
m_closeWindowAction->setEnabled(false);
m_closeAllWindowsAction = new KAction(i18n("Close All"), 0, this, TQT_SLOT(slotCloseAllWindows()), ac, "file_close_all");
@@ -534,8 +534,8 @@ void PartController::editDocumentInternal( const KURL & inputUrl, int lineNum,
else
{
MimeWarningDialog dlg;
- dlg.text2->setText( TQString( "<qt><b>%1</b></qt>" ).arg(url.path()));
- dlg.text3->setText( dlg.text3->text().arg(MimeType->name()) );
+ dlg.text2->setText( TQString( "<qt><b>%1</b></qt>" ).tqarg(url.path()));
+ dlg.text3->setText( dlg.text3->text().tqarg(MimeType->name()) );
if ( dlg.exec() == TQDialog::Accepted )
{
@@ -593,7 +593,7 @@ void PartController::showDocument(const KURL &url, bool newWin)
KParts::Factory *PartController::findPartFactory(const TQString &mimeType, const TQString &partType, const TQString &preferredName)
{
- KTrader::OfferList offers = KTrader::self()->query(mimeType, TQString("'%1' in ServiceTypes").arg(partType));
+ KTrader::OfferList offers = KTrader::self()->query(mimeType, TQString("'%1' in ServiceTypes").tqarg(partType));
if (offers.count() > 0)
{
@@ -694,7 +694,7 @@ void PartController::integratePart(KParts::Part *part, const KURL &url,
// Document object and our HTMLDocumentationPart
// connect(part, TQT_SIGNAL(fileNameChanged()), this, TQT_SLOT(slotFileNameChanged()));
// Connect to the document's views newStatus() signal in order to keep track of the
// modified-status of the document.
if (isTextEditor)
@@ -718,8 +718,8 @@ void PartController::integratePart(KParts::Part *part, const KURL &url,
connect(designerPart, TQT_SIGNAL(editSource(DesignerType, const TQString& )),
API::getInstance()->languageSupport(),
TQT_SLOT(openSource(DesignerType, const TQString& )));
- connect(designerPart, TQT_SIGNAL(newStatus(const TQString &, int)),
- this, TQT_SLOT(slotNewDesignerStatus(const TQString &, int)));
+ connect(designerPart, TQT_SIGNAL(newtqStatus(const TQString &, int)),
+ this, TQT_SLOT(slotNewDesignertqStatus(const TQString &, int)));
}
}
@@ -787,7 +787,7 @@ void PartController::integrateTextEditorPart(KTextEditor::Document* doc)
TQPtrListIterator<KTextEditor::View> it( list );
while ( it.current() )
{
- connect( it, TQT_SIGNAL( newStatus() ), this, TQT_SLOT( slotNewStatus() ) );
+ connect( it, TQT_SIGNAL( newtqStatus() ), this, TQT_SLOT( slotNewtqStatus() ) );
++it;
}
}
@@ -1005,7 +1005,7 @@ void PartController::reloadFile( const KURL & url )
if ( part->isModified() )
{
if ( KMessageBox::warningYesNo( TopLevel::getInstance()->main(),
- i18n( "The file \"%1\" is modified in memory. Are you sure you want to reload it? (Local changes will be lost.)" ).arg( url.path() ),
+ i18n( "The file \"%1\" is modified in memory. Are you sure you want to reload it? (Local changes will be lost.)" ).tqarg( url.path() ),
i18n( "File is Modified" ), i18n("Reload"), i18n("Do Not Reload") ) == KMessageBox::Yes )
{
part->setModified( false );
@@ -1120,7 +1120,7 @@ bool PartController::saveFile( const KURL & url, bool force )
case DirtyAndModified:
{
int code = KMessageBox::warningYesNoCancel( TopLevel::getInstance()->main(),
- i18n("The file \"%1\" is modified on disk.\n\nAre you sure you want to overwrite it? (External changes will be lost.)").arg( url.path() ),
+ i18n("The file \"%1\" is modified on disk.\n\nAre you sure you want to overwrite it? (External changes will be lost.)").tqarg( url.path() ),
i18n("File Externally Modified"), i18n("Overwrite"), i18n("Do Not Overwrite") );
if ( code == KMessageBox::Yes )
{
@@ -1481,7 +1481,7 @@ bool PartController::reactToDirty( KURL const & url, unsigned char reason )
{
KMessageBox::sorry( TopLevel::getInstance()->main(),
i18n("Conflict: The file \"%1\" has changed on disk while being modified in memory.\n\n"
- "You should investigate before saving to make sure you are not losing data.").arg( url.path() ),
+ "You should investigate before saving to make sure you are not losing data.").tqarg( url.path() ),
i18n("Conflict") );
return false;
}
@@ -1490,7 +1490,7 @@ bool PartController::reactToDirty( KURL const & url, unsigned char reason )
{
KMessageBox::sorry( TopLevel::getInstance()->main(),
i18n("Warning: The file \"%1\" has been deleted on disk.\n\n"
- "If this was not your intention, make sure to save this file now.").arg( url.path() ),
+ "If this was not your intention, make sure to save this file now.").tqarg( url.path() ),
i18n("File Deleted") );
return false;
}
@@ -1498,7 +1498,7 @@ bool PartController::reactToDirty( KURL const & url, unsigned char reason )
if ( dirtyAction == "alert" )
{
if ( KMessageBox::warningYesNo( TopLevel::getInstance()->main(),
- i18n("The file \"%1\" has changed on disk.\n\nDo you want to reload it?").arg( url.path() ),
+ i18n("The file \"%1\" has changed on disk.\n\nDo you want to reload it?").tqarg( url.path() ),
i18n("File Changed"), i18n("Reload"), i18n("Do Not Reload") ) == KMessageBox::No )
{
return false;
@@ -1511,14 +1511,14 @@ bool PartController::reactToDirty( KURL const & url, unsigned char reason )
return true;
}
-void PartController::slotNewDesignerStatus(const TQString &formName, int status)
+void PartController::slotNewDesignertqStatus(const TQString &formName, int status)
{
kdDebug(9000) << k_funcinfo << endl;
kdDebug(9000) << " formName: " << formName << ", status: " << status << endl;
emit documentChangedState( KURL::fromPathOrURL(formName), DocumentState(status) );
}
-void PartController::slotNewStatus( )
+void PartController::slotNewtqStatus( )
{
kdDebug(9000) << k_funcinfo << endl;
@@ -1628,7 +1628,7 @@ void PartController::slotBackAboutToShow()
TQValueList<HistoryEntry>::ConstIterator it = m_backHistory.begin();
while( i < 10 && it != m_backHistory.end() )
{
- popup->insertItem( (*it).url.fileName() + TQString(" (%1)").arg( (*it).line +1), (*it).id );
+ popup->insertItem( (*it).url.fileName() + TQString(" (%1)").tqarg( (*it).line +1), (*it).id );
++i;
++it;
}
@@ -1645,7 +1645,7 @@ void PartController::slotForwardAboutToShow( )
TQValueList<HistoryEntry>::ConstIterator it = m_forwardHistory.begin();
while( i < 10 && it != m_forwardHistory.end() )
{
- popup->insertItem( (*it).url.fileName() + TQString(" (%1)").arg( (*it).line +1), (*it).id );
+ popup->insertItem( (*it).url.fileName() + TQString(" (%1)").tqarg( (*it).line +1), (*it).id );
++i;
++it;
}
@@ -694,7 +694,7 @@ void PartController::integratePart(KParts::Part *part, const KURL &url,
// Document object and our HTMLDocumentationPart
// connect(part, TQT_SIGNAL(fileNameChanged()), this, TQT_SLOT(slotFileNameChanged()));
- // Connect to the document's views newStatus() signal in order to keep track of the
+ // Connect to the document's views newtqStatus() signal in order to keep track of the
// modified-status of the document.
if (isTextEditor)